package io.renren.modules.admin.controller;

import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;
import io.renren.modules.admin.entity.CompanyEntity;
import io.renren.modules.admin.service.CompanyService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.Map;



/**
 * 
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-17 13:23:33
 */
@RestController
@RequestMapping("admin/company")
public class CompanyController {
    @Autowired
    private CompanyService companyService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:company:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = companyService.queryPage(params);

        return R.ok().put("page", page);
    }


    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:company:info")
    public R info(@PathVariable("id") Long id){
		CompanyEntity company = companyService.getById(id);

        return R.ok().put("company", company);
    }

    /**
     *
     *
     *
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:company:save")
    public R save(@RequestBody CompanyEntity company){
        //创建时间
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-mm-dd hh:mm:ss");
        java.util.Date time = null;
        try {
            time= sdf.parse(sdf.format(new Date()));

        } catch (ParseException e) {
            e.printStackTrace();
        }
        company.setCreateTime(time);

		companyService.save(company);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:company:update")
    public R update(@RequestBody CompanyEntity company){
        //创建时间
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-mm-dd hh:mm:ss");
        java.util.Date time = null;
        try {
            time= sdf.parse(sdf.format(new Date()));

        } catch (ParseException e) {
            e.printStackTrace();
        }
        company.setModifyTime(time);
		companyService.updateById(company);

        return R.ok();
    }

    ///**
    // * 删除
    // */
    //@RequestMapping("/delete/{id}")
    //@RequiresPermissions("admin:company:delete")
    //public R delete(@PathVariable("id") Long id){
	//	//companyService.removeByIds(Arrays.asList(ids));
    //    boolean flag = companyService.delete(id);
    //
    //    if(flag){
    //        R.ok("逻辑删除成功");
    //    }
    //    return R.ok();
    //}


    /**
     * 逻辑删除
     */
    @RequestMapping("/delete")
    @RequiresPermissions("admin:company:delete")
    public R delete(@RequestBody Long[] ids){
        boolean flag = companyService.removeByIds(Arrays.asList(ids));
        if(flag){
            R.ok("逻辑删除成功");
        }
        return R.ok();
    }

}
