package io.renren.modules.admin.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.RandomStringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.common.annotation.SysLog;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;
import io.renren.common.validator.ValidatorUtils;
import io.renren.common.validator.group.AddGroup;
import io.renren.common.validator.group.UpdateGroup;
import io.renren.modules.admin.entity.EmployeeEntity;
import io.renren.modules.admin.service.EmployeeService;

/**
 * 
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-17 13:38:28
 */
@RestController
@RequestMapping("admin/employee")
public class EmployeeController {
    @Autowired
    private EmployeeService employeeService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:employee:list")
    public R list(@RequestParam Map<String, Object> params){
        Long companyId = 1L;
        PageUtils page = employeeService.queryPage(params,  companyId);

        return R.ok().put("page", page);
    }

    /**
     * 列表
     */
    @RequestMapping("/listtest")
    @RequiresPermissions("admin:employee:list")
    public R ListTest(@RequestParam Map<String, Object> params){
        String key = (String) params.get("key");
        int p = Integer.valueOf(params.get("page").toString());
        int limit = Integer.valueOf(params.get("limit").toString());
        PageUtils page = employeeService.queryList(p,limit, key);
        return R.ok().put("page",page);
    }

    /**
     * findAll
     */
    @RequestMapping("/findAllByisDel/{is_del}")
    @RequiresPermissions("admin:employee:findAllByisDel")
    public List<EmployeeEntity> findAllByisDel(@PathVariable("is_del") int isDel){
        List<EmployeeEntity> employeeEntityList = employeeService.findAllByisDel(isDel);
        return  employeeEntityList;
    }

    /**
     * findAllByTrueName
     */
    @RequestMapping("/findAllByTrueName")
    @RequiresPermissions("admin:employee:findAllByTrueName")
    public List<EmployeeEntity> findAllByTrueName(@RequestParam Map<String,Object> params){
        String truename = (String) params.get("truename");
        List<EmployeeEntity> allByTrueName = employeeService.findAllByTrueName(truename);
        return  allByTrueName;
    }

    /**
     * 信息
     */

    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:employee:info")
    public R info(@PathVariable("id") Long id){
		EmployeeEntity employee = employeeService.getById(id);
        
        return R.ok().put("employee", employee);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:employee:save")
    public R save(@RequestBody EmployeeEntity employee){
        ValidatorUtils.validateEntity(employee, AddGroup.class);
        employee.setCompanyId(1L);
        employeeService.saveEmployee(employee);
        
        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:employee:update")
    public R update(@RequestBody EmployeeEntity employee){
        ValidatorUtils.validateEntity(employee, UpdateGroup.class);

        employeeService.updateEmployee(employee);
        
        return R.ok();
    }

    /**
     * 逻辑删除
     */
    @RequestMapping("/delete")
    @RequiresPermissions("admin:employee:delete")
    public R delete(@RequestBody Long[] ids){
        employeeService.removeByIds(Arrays.asList(ids));
        
        return R.ok();
    }

    /**
     * 重置密码
     */
    @SysLog("重置密码")
    @PostMapping("/repassword/{id}")
    @RequiresPermissions("admin:employee:repassword")
    public R repassword(@PathVariable("id") Long id){
        EmployeeEntity employee = employeeService.getById(id);
        employee.setPassword("123456");
        employeeService.updateEmployee(employee);

        return R.ok();
    }

    /**
     * 模糊查询name获取list
     */
    @GetMapping("/listbyname")
    @RequiresPermissions("admin:employee:list")
    public R listByName(@RequestParam Map<String,Object> params){
        Long companyId = 1L;
        String truename = (String) params.get("truename");
        List<Map<String, Object>> list = employeeService.selectNameList(truename, companyId);
        return  R.ok().put("list", list);
    }

    /**
     * 根据company_id获取 employee id,name(获得id在分配人员时使用)
     */
    @GetMapping("/listbycid/{cid}")
    @RequiresPermissions("admin:employee:list")
    public R selectNameListByCompanyId(@PathVariable("cid") Long cid) {
        Map<Long, String> list = employeeService.selectNameListByCompanyId(cid);
        return  R.ok().put("list", list);
    }
    // 默认单位id1
    @GetMapping("/listbycid")
    @RequiresPermissions("admin:employee:list")
    public R selectNameListByCompanyId() {
        Map<Long, String> list = employeeService.selectNameListByCompanyId(1L);
        return  R.ok().put("list", list);
    }
}
