package io.renren.modules.admin.service.impl;

import org.apache.commons.lang.RandomStringUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.Query;

import io.renren.modules.admin.dao.EmployeeDao;
import io.renren.modules.admin.entity.EmployeeEntity;
import io.renren.modules.admin.service.EmployeeService;


@Service("employeeService")
public class EmployeeServiceImpl extends ServiceImpl<EmployeeDao, EmployeeEntity> implements EmployeeService {

    @Override
    public PageUtils queryPage(Map<String, Object> params) {
        Long companyId = params.containsKey("companyId") ? Long.valueOf((String) params.get("companyId")) : 1L;
        String key = (String) params.get("key");
        IPage<EmployeeEntity> page = this.page(
                new Query<EmployeeEntity>().getPage(params),
                new QueryWrapper<EmployeeEntity>()
                .eq("company_id", companyId)
                .like(StringUtils.isNotBlank(key),"username",key)
                        .or()
                .like(StringUtils.isNotBlank(key),"truename",key)
        );

        return new PageUtils(page);
    }
    
    @Override
    public PageUtils queryPage(Map<String, Object> params, Long companyId) {
        String key = (String) params.get("key");
        IPage<EmployeeEntity> page = this.page(
                new Query<EmployeeEntity>().getPage(params),
                new QueryWrapper<EmployeeEntity>()
                .eq("company_id", companyId)
                .like(StringUtils.isNotBlank(key),"username",key)
                        .or()
                .like(StringUtils.isNotBlank(key),"truename",key)
        );

        return new PageUtils(page);
    }
    

    @Override
    public PageUtils myQueryPage(Map<String, Object> params) {
        // Long company_id = params.containsKey("company_id") ? Long.valueOf((String) params.get("company_id")) : 1;
        String key = params.containsKey("page") ? (String) params.get("key") : "";
        int page = params.containsKey("page") ? Integer.valueOf(params.get("page").toString()): 1;
        int limit = params.containsKey("limit") ? Integer.valueOf(params.get("limit").toString()) : 10;

        if (page < 1) {
            page = 1;
        }
        int startLimt = (page-1) * limit;
        int endLimt = startLimt + limit;

        List<Map<String, Object>> employeeList=baseMapper.getPageList(key, key, startLimt, endLimt);
        int total = baseMapper.getCounts(key, key);

        return  new  PageUtils(employeeList, total, limit, page);
    }

    @Override
    public List<EmployeeEntity> findAllByisDel(int isDel) {
        return  baseMapper.findAllByisDel(isDel);
    }

    @Override
    public List<EmployeeEntity> findAllByTrueName(String truename) {
        return baseMapper.findAllByTrueName(truename);
    }

    @Override
    public PageUtils queryList(int page, int limit, String key) {
        System.out.println(page);
        System.out.println(limit);
        System.out.println(key);
        List<Map<String, Object>> mList = baseMapper.queryListBykey(key, key,page, limit);
        Integer total = baseMapper.queryTotalCount(key, key);


        return new PageUtils(mList,total,limit,page);
    }

    @Override
    public List<Map<String, Object>> selectNameList(String truename, Long companyId) {
        return baseMapper.selectNameList(truename, companyId);
    }

    @Override
    public Map<Long, String> selectNameListByCompanyId(Long companyId) {
        List<Map<String, Object>> list= baseMapper.selectNameListByCompanyId(companyId);
        Map<Long, String> result = new HashMap<Long, String>();
        for (Map<String,Object> map : list) {
            Long id =(Long) map.get("id");
            String name = (String) map.get("truename");
            result.put(id, name);
        }

        return result;
    }

    @Override
    public List<Map<String, Object>> getContact(String ids) {
        return baseMapper.getContact(ids);
    }

    @Override
    public void saveEmployee(EmployeeEntity employee) {
        // if(StringUtils.isBlank(employee.getPassword())){
        //     employee.setPassword("123456");
        // }
        employee.setPassword("123456");
        employee.setCreateTime(new Date());
        String salt = RandomStringUtils.randomAlphanumeric(20);
        employee.setPassword(new Sha256Hash(employee.getPassword(), salt).toHex());
        employee.setSalt(salt);

        this.save(employee);
    }

    @Override
    public void updateEmployee(EmployeeEntity employee) {
        employee.setModifyTime(new Date());
        // if(StringUtils.isBlank(employee.getPassword())){
		// 	employee.setPassword(null);
		// }else{
        //     String salt = RandomStringUtils.randomAlphanumeric(20);
        //     employee.setPassword(new Sha256Hash(employee.getPassword(), salt).toHex());
        //     employee.setSalt(salt);
        // }
        employee.setPassword(null);
        this.updateById(employee);
    }
}