/**
 * Copyright (c) 2016-2019 人人开源 All rights reserved.
 *
 * https://www.renren.io
 *
 * 版权所有，侵权必究！
 */

package io.renren.modules.app.controller;

import io.renren.common.utils.R;
import io.renren.common.validator.Assert;
import io.renren.common.validator.ValidatorUtils;
import io.renren.modules.app.entity.UserEntity;
import io.renren.modules.app.form.RegisterForm;
import io.renren.modules.app.service.SmsCodeService;
import io.renren.modules.app.service.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 注册
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestController
@RequestMapping("/app")
@Api("APP注册接口")
public class AppRegisterController {
    @Autowired
    private UserService userService;

    @Autowired
    private SmsCodeService smsCodeService;

    /**
     * 注册短信验证码
     */
    @PostMapping("/mobilecode")
    public R mobileCode(@RequestBody Map<String, Object> params) {
        String uuid = (String) params.get("uuid");
        String phone = (String) params.get("phone");

        Assert.isNotPhone(phone);

        Assert.isBlank(uuid, "uuid不能为空");

        UserEntity user = userService.queryByUsername(phone);
        if (user != null) {
            return R.error("手机号已注册");
        }

        try {
            String result = smsCodeService.getCode(uuid, phone);
            return R.ok().put("result", result);
        } catch (Exception e) {
            e.printStackTrace();
            return R.error();
        }
    }

    @PostMapping("register")
    @ApiOperation("注册")
    public R register(@RequestBody RegisterForm form){
        boolean captcha = smsCodeService.validate(form.getUuid(), form.getCode(), form.getPhone());
		if(!captcha){
			return R.error("验证码不正确");
        }
        
        //表单校验
         ValidatorUtils.validateEntity(form);

         UserEntity user = new UserEntity();
         user.setPhone(form.getPhone());
         user.setUsername(form.getPhone());
         user.setPassword(form.getPassword());
         userService.saveUser(user);

        return R.ok();
    }
    
    /**
     * 找回密码短信验证码
     */
    @PostMapping("/phonecode")
    public R phoneCode(@RequestBody Map<String, Object> params) {
        String uuid = (String) params.get("uuid");
        String phone = (String) params.get("phone");

        UserEntity user = userService.queryByUsername(phone);
        if (user == null) {
            return R.error("手机号未注册");
        }

        try {
            String result = smsCodeService.getCode(uuid, phone);
            return R.ok().put("result", result);
        } catch (Exception e) {
            e.printStackTrace();
            return R.error();
        }
    }

    /**
     * 通过手机验证码重置密码
     * @param form
     * @return
     */
    @PostMapping("repassword")
    @ApiOperation("通过手机验证码重置密码")
    public R rePassword(@RequestBody RegisterForm form){
        boolean captcha = smsCodeService.validate(form.getUuid(), form.getCode(), form.getPhone());
		if(!captcha){
			return R.error("验证码不正确");
        }
        
        //表单校验
        ValidatorUtils.validateEntity(form);

        UserEntity user = userService.queryByUsername(form.getPhone());
        Long userId = user.getUserId();
        userService.updatePassWord(userId, form.getPassword());

        return R.ok();
    }
}
